@@ -1,9 +1,10 @@
 "bugs" <-
-function (data, inits, parameters.to.save, model.file = "model.txt",
+function(data, inits, parameters.to.save, model.file = "model.txt",
     n.chains = 3, n.iter = 2000, n.burnin = floor(n.iter / 2),
     n.thin = max(1, floor(n.chains * (n.iter - n.burnin) / 1000)), debug = FALSE,
     DIC = TRUE, digits = 5, codaPkg = FALSE, 
     bugs.directory = "c:/Program Files/WinBUGS14/", working.directory = NULL){
+
   # Checking number of inits, which is NOT save here:
   if(!missing(inits) && !is.function(inits) && (length(inits) != n.chains)) 
     stop("Number of initialized chains (length(inits)) != n.chains")
@@ -13,7 +14,11 @@ function (data, inits, parameters.to.save, model.file = "model.txt",
       on.exit(setwd(savedWD))
   }
   if(!file.exists(model.file)) stop(paste(model.file, "does not exist."))
-  bugs.data.inits(data, inits, n.chains, digits)
+  if(!(length(data) == 1 && is.vector(data) && is.character(data) && data == "data.txt"))
+    bugs.data(data, dir = getwd(), digits)  
+  else if(!file.exists(data))
+    stop("File data.txt does not exist.")
+  bugs.inits(inits, n.chains, digits)
   if(DIC) parameters.to.save <- c(parameters.to.save, "deviance")
   # Model files with extension ".bug" need to be renamed to ".txt"
   if(length(grep("\\.bug$", model.file))){
